@@ -100,7 +100,7 @@ main(int  argc,				/* I - Number of command-line arguments (6 or 7) */
   }
   else if (argc < 6 || argc > 7)
   {
-    fprintf(stderr, "Usage: %s job-id user title copies options [file]",
+    fprintf(stderr, "Usage: %s job-id user title copies options [file]\n",
             argv[0]);
     return (CUPS_BACKEND_FAILED);
   }
